@@ -8,10 +8,8 @@ def RealPathname(*args)
   RealPathname.new(*args)
 end
 
-if RUBY_VERSION >= '1.9.3'
-  def Pathname(*args)
-    Pathname.new(*args)
-  end
+def Pathname(*args)
+  Pathname.new(*args)
 end
 
 # FakeFS module
@@ -21,19 +19,20 @@ module FakeFS
       @activated ? true : false
     end
 
+    # unconditionally activate
     def activate!
       Object.class_eval do
         remove_const(:Dir)
         remove_const(:File)
         remove_const(:FileTest)
         remove_const(:FileUtils)
-        remove_const(:Pathname) if RUBY_VERSION >= '1.9.3'
+        remove_const(:Pathname)
 
         const_set(:Dir,       FakeFS::Dir)
         const_set(:File,      FakeFS::File)
         const_set(:FileUtils, FakeFS::FileUtils)
         const_set(:FileTest,  FakeFS::FileTest)
-        const_set(:Pathname,  FakeFS::Pathname) if RUBY_VERSION >= '1.9.3'
+        const_set(:Pathname,  FakeFS::Pathname)
         ::FakeFS::Kernel.hijack!
       end
 
@@ -42,19 +41,20 @@ module FakeFS
       true
     end
 
+    # unconditionally deactivate
     def deactivate!
       Object.class_eval do
         remove_const(:Dir)
         remove_const(:File)
         remove_const(:FileTest)
         remove_const(:FileUtils)
-        remove_const(:Pathname) if RUBY_VERSION >= '1.9.3'
+        remove_const(:Pathname)
 
         const_set(:Dir,       RealDir)
         const_set(:File,      RealFile)
         const_set(:FileTest,  RealFileTest)
         const_set(:FileUtils, RealFileUtils)
-        const_set(:Pathname,  RealPathname) if RUBY_VERSION >= '1.9.3'
+        const_set(:Pathname,  RealPathname)
         ::FakeFS::Kernel.unhijack!
       end
 
@@ -63,6 +63,18 @@ module FakeFS
       true
     end
 
+    # unconditionally clear the fake filesystem
+    def clear!
+      ::FakeFS::FileSystem.clear
+    end
+
+    # present a fresh new fake filesystem to the block
+    def with_fresh(&block)
+      clear!
+      with(&block)
+    end
+
+    # present the fake filesystem to the block
     def with
       if activated?
         yield
@@ -76,6 +88,7 @@ module FakeFS
       end
     end
 
+    # present a non-fake filesystem to the block
     def without
       if !activated?
         yield
