@@ -1,17 +1,14 @@
 module FakeFS
   # Fake file class
   class FakeFile
-    attr_accessor :name, :parent, :content, :mtime, :atime, :mode, :uid, :gid
+    attr_accessor :name, :parent, :mtime, :atime, :mode, :uid, :gid
     attr_reader :ctime, :birthtime
 
     # Inode class
     class Inode
       def initialize(file_owner)
-        # 1.9.3 when possible set default external encoding
-        @content = ''
-        @content = ''.encode(
-          Encoding.default_external) if ''.respond_to?(:encode)
-        @links   = [file_owner]
+        @content = ''.encode(Encoding.default_external)
+        @links = [file_owner]
       end
 
       attr_accessor :content
@@ -41,7 +38,7 @@ module FakeFS
       @mtime     = @ctime
       @atime     = @ctime
       @birthtime = @ctime
-      @mode      = 0100000 + (0666 - File.umask)
+      @mode      = 0o100000 + (0o666 - File.umask)
       @uid       = Process.uid
       @gid       = Process.gid
     end
