@@ -1,4 +1,4 @@
-$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '..', 'lib')
+require 'bundler/setup'
 require 'fakefs/safe'
 require 'minitest/autorun'
 require 'minitest/rg'
@@ -15,7 +15,7 @@ def capture_stderr
 
   yield
 
-  return $stderr.string
+  $stderr.string
 ensure
   $stderr = real_stderr
 
